감 사 결 과

| 지적 및 조치 요구 |
| :--- |
| ❍ 청탁금지법 위반  - A는 2021년 10월 문체부 감사 당시 상급자 B의 자녀 결혼식에 축의금 한도액을 초과하는 20만 원을 지급하는 등 청탁금지법을 위반한 사실이 적발되었으나, 이를 숨길 목적으로 동료직원 3명과 B에게 허위진술을 요청함   - 당시 상급자 B는 청탁금지법을 위반하여 축의금 한도액을 초과하여 지급한 직원들에게 초과분을 모두 되돌려 주었고, A도 B로부터 초과액 15만 원을 돌려받았으나 어떠한 적절한 조치(4명이 5만 원씩 각출 시 B에게 돌려주는 등)도 취하지 않음 ❍ 성실의무 위반  - A는 상급자 B의 자녀 결혼축의금으로 20만 원을 지급하여 청탁금지법을 위반하였음에도, 2021년 10월 문체부 감사 당시 C, D, E를 포함하여 4명이 5만 원씩 각출하여 20만 원을 냈다고 허위 진술하였고, 이들 3명도 같은 내용으로 확인서를 작성함에 따라 A가 징계 대상에서 제외되었음. 2021년 10월 거짓 진술한 내용을 뒷받침하기 위해 본 감사에서도 거짓 진술을 하는 등 본인의 잘못을 부인하는 등 뉘우침이 없음  ☞ 청탁금지법을 위반하고 허위 진술을 하는 등 성실의무를 위반한 A에 대해 “경징계”, “징계부가금(1배 이내)” 조치할 것  ☞ 허위 확인서를 제출하는 등 성실의무를 위반한 C, D, E에 대해 “주의” 조치할 것 |

